Learn R Programming

nmadb (version 1.2.0)

getNMADB: NMA catalog

Description

Petropoulou et al. compiled a database of network meta-analyses to serve as a source for empirical studies Petropoulou (2016). The database is hosted in a REDcap database at the Institute of Social and Preventive Medicine (ISPM) in the University of Bern. Function getNMADB downloads the list of networks included in Petropoulou (2016).

Usage

getNMADB()

Arguments

Value

A data.frame with the network meta-analyses included in [1]. Several characterstics related to the publications (e.g. Journal.Name, Title) are included in the data.frame.

References

Petropoulou M, Nikolakopoulou A A, Veroniki A, Rios P, Vafaei A, Zarin W, Giannatsi M, Sullivan S, Tricco A C, Chaimani A, Egger M, Salanti G (2016) <doi:10.1016/j.jclinepi.2016.11.002>.

Examples

Run this code
# NOT RUN {
catalog = getNMADB()
# }
# NOT RUN {
  Networks that labeled Verified have outcome data 
  that allow the analysis to be repeated.
# }
# NOT RUN {
nmalist = catalog[catalog$Verified=="True",]
nmalist
# }

Run the code above in your browser using DataLab